@@ -1,5 +1,6 @@
 #include "defines.hpp"
 #include "helpers/Logger.hpp"
+#include "helpers/GlobalState.hpp"
 #include "ui/UI.hpp"
 #include "config/ConfigManager.hpp"
 
@@ -25,13 +26,16 @@ int main(int argc, const char** argv, const char** envp) {
         return 0;
     }
 
-    if (parser.getBool("verbose").value_or(false))
+    if (parser.getBool("verbose").value_or(false)) {
         g_logger->setLogLevel(LOG_TRACE);
+        g_state->verbose = true;
+    }
 
     g_logger->log(LOG_DEBUG, "Welcome to hyprpaper!\nbuilt from commit {} ({})", GIT_COMMIT_HASH, GIT_COMMIT_MESSAGE);
 
     g_config = makeUnique<CConfigManager>(std::string{parser.getString("config").value_or("")});
-    g_config->init();
+    if (!g_config->init())
+        return 1;
 
     g_ui = makeUnique<CUI>();
     g_ui->run();
